Pyramid Duh
===========
:Build: |build|_ |coverage|_
:Documentation: http://pyramid_duh.readthedocs.org/en/latest/
:Source: https://github.com/stevearc/pyramid_duh

.. |build| image:: https://travis-ci.org/stevearc/pyramid_duh.png?branch=master
.. _build: https://travis-ci.org/stevearc/pyramid_duh
.. |coverage| image:: https://coveralls.io/repos/stevearc/pyramid_duh/badge.png?branch=master
.. _coverage: https://coveralls.io/r/stevearc/pyramid_duh?branch=master

This is just a collection of utilities that I found myself putting into *every
single* pyramid project I made. So now they're all in one place.
